==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/KPIHISTORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour KPIHISTORYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="KPIHISTORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPDDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "KPIHISTORYID_Type", propOrder = {
    "homeid",
    "upddate"
})
public class KPIHISTORYID_Type {

    @XmlElement(name = "HOMEID", required = true)
    protected HOMEID_Type homeid;
    @XmlElement(name = "UPDDATE", required = true)
    protected DATETIME upddate;

    /**
     * Obtient la valeur de la propriété homeid.
     * 
     * @return
     *     possible object is
     *     {@link HOMEID_Type }
     *     
     */
    public HOMEID_Type getHOMEID() {
        return homeid;
    }

    /**
     * Définit la valeur de la propriété homeid.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEID_Type }
     *     
     */
    public void setHOMEID(HOMEID_Type value) {
        this.homeid = value;
    }

    /**
     * Obtient la valeur de la propriété upddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUPDDATE() {
        return upddate;
    }

    /**
     * Définit la valeur de la propriété upddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUPDDATE(DATETIME value) {
        this.upddate = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/KPIHISTORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for KPIHISTORYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="KPIHISTORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPDDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "KPIHISTORYID_Type", propOrder = {
    "homeid",
    "upddate"
})
public class KPIHISTORYID_Type {

    @XmlElement(name = "HOMEID", required = true)
    protected HOMEID_Type homeid;
    @XmlElement(name = "UPDDATE", required = true)
    protected DATETIME upddate;

    /**
     * Gets the value of the homeid property.
     * 
     * @return
     *     possible object is
     *     {@link HOMEID_Type }
     *     
     */
    public HOMEID_Type getHOMEID() {
        return homeid;
    }

    /**
     * Sets the value of the homeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEID_Type }
     *     
     */
    public void setHOMEID(HOMEID_Type value) {
        this.homeid = value;
    }

    /**
     * Gets the value of the upddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUPDDATE() {
        return upddate;
    }

    /**
     * Sets the value of the upddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUPDDATE(DATETIME value) {
        this.upddate = value;
    }

}
